Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(985)

Unified Diff: Source/core/paint/BoxDecorationData.h

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/page/TouchAdjustment.cpp ('k') | Source/core/paint/BoxDecorationData.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/paint/BoxDecorationData.h
diff --git a/Source/core/paint/BoxDecorationData.h b/Source/core/paint/BoxDecorationData.h
index 63087ffba95cdcb99333e2adec72a4e18bbaf022..7dfbdacc28cc40475836fc59924b6c89eb67df12 100644
--- a/Source/core/paint/BoxDecorationData.h
+++ b/Source/core/paint/BoxDecorationData.h
@@ -13,7 +13,7 @@ namespace blink {
class GraphicsContext;
class LayoutBox;
// Information extracted from LayoutStyle for box painting.
class BoxDecorationData {
public:
BoxDecorationData(const LayoutBox&, GraphicsContext*);
@@ -26,7 +26,7 @@ public:
private:
BackgroundBleedAvoidance determineBackgroundBleedAvoidance(const LayoutBox&, GraphicsContext*);
- bool borderObscuresBackgroundEdge(const LayoutStyle&, const FloatSize& contextScale) const;
+ bool borderObscuresBackgroundEdge(const ComputedStyle&, const FloatSize& contextScale) const;
unsigned m_bleedAvoidance : 2; // BackgroundBleedAvoidance
};
« no previous file with comments | « Source/core/page/TouchAdjustment.cpp ('k') | Source/core/paint/BoxDecorationData.cpp » ('j') | no next file with comments »
@@ -13,7 +13,7 @@ namespace blink {
class GraphicsContext;
class LayoutBox;
-// Information extracted from LayoutStyle for box painting.
+// Information extracted from ComputedStyle for box painting.
class BoxDecorationData {
public:

Powered by Google App Engine
This is Rietveld 408576698